@@ -3,7 +3,7 @@
   
   #need to check if proper Java is installed by special request of Prof Brian Ripley
   jv = .jcall("java/lang/System", "S", "getProperty", "java.runtime.version")
-  if (substr(jv, 1L, 1L) == "1") {
+  if (substr(jv, 1L, 2L) == "1.") {
 	  jvn = as.numeric(paste0(strsplit(jv, "[.]")[[1L]][1:2], collapse = "."))
 	  if (jvn < 1.7){
 	  	stop("Java 7 (at minimum) is needed for this package but is not available.")
@@ -22,4 +22,4 @@
 			"If you run out of memory, restart R, and use e.g.\n'options(java.parameters = \"-Xmx5g\")' for 5GB of RAM before you call\n'library(bartMachine)'.\n",
 			sep = "")
   )
-}
\ No newline at end of file
+}
